@@ -1,6 +1,3 @@
-#![macro_use]
-// use cassandra_sys;
-
 use cassandra::consistency::Consistency;
 use cassandra::util::Protected;
 use cassandra::write_type::WriteType;
@@ -29,7 +26,7 @@ use std::ffi::{CStr, CString};
 use std::fmt::{Debug, Display, Formatter};
 use std::os::raw::c_char;
 
-/// Define the errors that may be returned by this driver.
+// Define the errors that may be returned by this driver.
 error_chain! {
     foreign_links {
         StringContainsNul(::std::ffi::NulError)
